'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var kebabCase = require('lodash/fp/kebabCase');
var mapValues = require('lodash/fp/mapValues');
var curry = require('lodash/fp/curry');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var kebabCase__default = /*#__PURE__*/_interopDefaultLegacy(kebabCase);
var mapValues__default = /*#__PURE__*/_interopDefaultLegacy(mapValues);
var curry__default = /*#__PURE__*/_interopDefaultLegacy(curry);

var ICON_MAP = {
    success: {
        name: 'check-circle',
    },
    info: {
        name: 'info-circle',
    },
    warning: {
        name: 'exclamation-triangle',
    },
    danger: {
        name: 'exclamation-circle',
    },
};
var THEME_COLOR_TOKEN_MAP = {
    default: 'cool-gray-lighter',
    primary: 'primary-brand-accent',
    success: 'ui-success',
    info: 'primary-brand-accent',
    warning: 'ui-warning',
    'warning-light': 'ui-warning-lightest',
    danger: 'ui-danger',
    dark: 'support-black',
    light: 'white',
};

var forkHandlers = function (handlers) { return function (e) {
    handlers.forEach(function (handler) {
        if (handler)
            handler(e);
    });
}; };

function parseMetadata(metadata) {
    return metadata
        ? Object.keys(metadata).reduce(function (acc, key) {
            acc["data-" + kebabCase__default['default'](key)] = metadata[key] || '';
            return acc;
        }, {})
        : {};
}
/**
 * This function allows to generate a new object that
 * contains metadata with values suffixed with provided suffix
 *
 * @example
 *   ```ts
 *   suffixMetadata(metadata, 'inner')
 *   ```
 *
 * This function is curried:
 *
 * @example
 *   ```ts
 *   const { metadata } = props;
 *   const suffixedMeta = suffixMetadata(metadata);
 *   ...
 *   <div {...parseMetadata(suffixedMeta('innerPart1'))}>
 *     <div {...parseMetadata(suffixedMeta('innerPart2'))} />
 *   </div>
 *   ```
 *
 * @param {ComponentMetadata} metadata The original metadata object
 * @param {string} suffix A string to be added to the values of the original metadata object
 * @returns {ComponentMetadata} The metadata object with values containing suffixes
 */
var suffixMetadata = curry__default['default'](function (metadata, suffix) { return mapValues__default['default'](function (val) { return val + "-" + suffix; }, metadata); });

exports.ICON_MAP = ICON_MAP;
exports.THEME_COLOR_TOKEN_MAP = THEME_COLOR_TOKEN_MAP;
exports.forkHandlers = forkHandlers;
exports.parseMetadata = parseMetadata;
exports.suffixMetadata = suffixMetadata;
//# sourceMappingURL=index.js.map
